#Urdu Digit

A package to help convert digits from their English equivalent to their Urdu equivalent.


#Details

Simply, this package relies on unicode conversion between the 2 languages.


#Usage

import urdu_digit as ud

&#35; to just GET the conversion of, for e.g: 2;

ud.get(2)

&#35; OUTPPUT: (2, '۲', '0x6f2')

&#35; to PRINT the conversion of, for e.g: 7:

ud.view(7)

&#35; OUTPPUT: (7, '۷', '0x6f7')
#Output


